@@ -32,6 +32,10 @@ public class Zip4jUtil {
   private static final long DOSTIME_BEFORE_1980 = (1 << 21) | (1 << 16);
   private static final int MAX_RAW_READ_FULLY_RETRY_ATTEMPTS = 15;
 
+  public static boolean isStringNullOrEmpty(String str) {
+    return str == null || str.trim().length() == 0;
+  }
+
   public static boolean isStringNotNullAndNotEmpty(String str) {
     return str != null && str.trim().length() > 0;
   }
@@ -97,28 +101,19 @@ public class Zip4jUtil {
     return cal.getTime().getTime();
   }
 
-  public static byte[] convertCharArrayToByteArray(char[] charArray) {
-    try {
-      ByteBuffer buf = InternalZipConstants.CHARSET_UTF_8.encode(CharBuffer.wrap(charArray));
-      byte[] bytes = new byte[buf.limit()];
-      buf.get(bytes);
-      return bytes;
-    } catch (Exception e) {
-      byte[] bytes = new byte[charArray.length];
-      for (int i = 0; i < charArray.length; i++) {
-        bytes[i] = (byte) charArray[i];
-      }
-      return bytes;
-    }
+  public static byte[] convertCharArrayToByteArray(char[] charArray, boolean useUtf8Charset) {
+    return useUtf8Charset
+            ? convertCharArrayToByteArrayUsingUtf8(charArray)
+            : convertCharArrayToByteArrayUsingDefaultCharset(charArray);
   }
 
-  public static CompressionMethod getCompressionMethod(AbstractFileHeader localFileHeader) {
+  public static CompressionMethod getCompressionMethod(AbstractFileHeader localFileHeader) throws ZipException {
     if (localFileHeader.getCompressionMethod() != CompressionMethod.AES_INTERNAL_ONLY) {
       return localFileHeader.getCompressionMethod();
     }
 
     if (localFileHeader.getAesExtraDataRecord() == null) {
-      throw new RuntimeException("AesExtraDataRecord not present in local header for aes encrypted data");
+      throw new ZipException("AesExtraDataRecord not present in local header for aes encrypted data");
     }
 
     return localFileHeader.getAesExtraDataRecord().getCompressionMethod();
@@ -128,6 +123,10 @@ public class Zip4jUtil {
 
     int readLen = inputStream.read(bufferToReadInto);
 
+    if (readLen == -1) {
+      throw new IOException("Unexpected EOF reached when trying to read stream");
+    }
+
     if (readLen != bufferToReadInto.length) {
       readLen = readUntilBufferIsFull(inputStream, bufferToReadInto, readLen);
 
@@ -175,6 +174,13 @@ public class Zip4jUtil {
 
   private static int readUntilBufferIsFull(InputStream inputStream, byte[] bufferToReadInto, int readLength)
       throws IOException {
+    if (readLength < 0) {
+      throw new IOException("Invalid readLength");
+    }
+
+    if (readLength == 0) {
+      return 0;
+    }
 
     int remainingLength = bufferToReadInto.length - readLength;
     int loopReadLength = 0;
@@ -197,4 +203,23 @@ public class Zip4jUtil {
     return readLength;
   }
 
+  private static byte[] convertCharArrayToByteArrayUsingUtf8(char[] charArray) {
+    try {
+      ByteBuffer buf = InternalZipConstants.CHARSET_UTF_8.encode(CharBuffer.wrap(charArray));
+      byte[] bytes = new byte[buf.limit()];
+      buf.get(bytes);
+      return bytes;
+    } catch (Exception e) {
+      return convertCharArrayToByteArrayUsingDefaultCharset(charArray);
+    }
+  }
+
+  private static byte[] convertCharArrayToByteArrayUsingDefaultCharset(char[] charArray) {
+    byte[] bytes = new byte[charArray.length];
+    for (int i = 0; i < charArray.length; i++) {
+      bytes[i] = (byte) charArray[i];
+    }
+    return bytes;
+  }
+
 }
