@@ -8,6 +8,7 @@ import net.lingala.zip4j.model.enums.AesKeyStrength;
 import net.lingala.zip4j.model.enums.CompressionLevel;
 import net.lingala.zip4j.model.enums.CompressionMethod;
 import net.lingala.zip4j.model.enums.EncryptionMethod;
+import net.lingala.zip4j.testutils.TestUtils;
 import net.lingala.zip4j.testutils.ZipFileVerifier;
 import net.lingala.zip4j.util.FileUtils;
 import net.lingala.zip4j.util.InternalZipConstants;
@@ -19,6 +20,9 @@ import org.junit.rules.ExpectedException;
 import java.io.File;
 import java.io.FilenameFilter;
 import java.io.IOException;
+import java.io.InputStream;
+import java.nio.file.Files;
+import java.nio.file.Path;
 import java.util.ArrayList;
 import java.util.List;
 
@@ -281,6 +285,66 @@ public class CreateZipFileIT extends AbstractIT {
     verifyZipFileByExtractingAllFiles(generatedZipFile, outputFolder, 3);
   }
 
+  @Test
+  public void testCreateZipFileFromStreamThrowsExceptionIfZipFileExists() throws IOException {
+    try (ZipFile zipFile = new ZipFile(generatedZipFile)) {
+      zipFile.addFile(TestUtils.getTestFileFromResources("sample.pdf"));
+    }
+
+    expectedException.expect(ZipException.class);
+    expectedException.expectMessage("zip file: " + generatedZipFile
+            + " already exists. To add files to existing zip file use addFile method");
+
+    try (ZipFile zipFile = new ZipFile(generatedZipFile)) {
+      zipFile.createSplitZipFile((InputStream) null, new ZipParameters(), true, 512000);
+    }
+  }
+
+  @Test
+  public void testCreateZipFileFromStreamCreatesSplitFileSuccessfully() throws IOException {
+    Path fileToAdd = TestUtils.getTestFileFromResources("file_PDF_1MB.pdf").toPath();
+    ZipParameters zipParameters = new ZipParameters();
+    zipParameters.setFileNameInZip(fileToAdd.getFileName().toString());
+
+    try (ZipFile zipFile = new ZipFile(generatedZipFile);
+         InputStream inputStream = Files.newInputStream(fileToAdd)) {
+      zipFile.createSplitZipFile(inputStream, zipParameters, true, 512000);
+    }
+
+    verifyZipFileByExtractingAllFiles(generatedZipFile, null, outputFolder, 1);
+    verifySplitZip(generatedZipFile, 2, 512000);
+  }
+
+  @Test
+  public void testCreateZipFileFromStreamCreatesNonSplitFileWhenFlagIsFalse() throws IOException {
+    Path fileToAdd = TestUtils.getTestFileFromResources("file_PDF_1MB.pdf").toPath();
+    ZipParameters zipParameters = new ZipParameters();
+    zipParameters.setFileNameInZip(fileToAdd.getFileName().toString());
+
+    try (ZipFile zipFile = new ZipFile(generatedZipFile);
+         InputStream inputStream = Files.newInputStream(fileToAdd)) {
+      zipFile.createSplitZipFile(inputStream, zipParameters, false, 512000);
+    }
+
+    verifyZipFileByExtractingAllFiles(generatedZipFile, null, outputFolder, 1);
+    verifySplitZip(generatedZipFile, 1, 512000);
+  }
+
+  @Test
+  public void testCreateZipFileFromStreamCreatesNonSplitFileWhenSplitLengthIsLowerThanFileLength() throws IOException {
+    Path fileToAdd = TestUtils.getTestFileFromResources("sample.pdf").toPath();
+    ZipParameters zipParameters = new ZipParameters();
+    zipParameters.setFileNameInZip(fileToAdd.getFileName().toString());
+
+    try (ZipFile zipFile = new ZipFile(generatedZipFile);
+         InputStream inputStream = Files.newInputStream(fileToAdd)) {
+      zipFile.createSplitZipFile(inputStream, zipParameters, true, 512000);
+    }
+
+    verifyZipFileByExtractingAllFiles(generatedZipFile, null, outputFolder, 1);
+    verifySplitZip(generatedZipFile, 1, 512000);
+  }
+
   private void verifySplitZip(File zipFile, int numberOfExpectedSplitFiles, long splitLength) throws ZipException {
     assertNumberOfSplitFile(zipFile, numberOfExpectedSplitFiles);
     assertSplitFileSizes(zipFile, numberOfExpectedSplitFiles, splitLength);
